@@ -9,7 +9,6 @@ class MySQLClient:
         :param dbdata host 主机地址,user 用户名,password 密码,database 数据库,port 端口，默认3306
         :return {bool} True/False
         '''
-        print('执行了一次')
         # 打开数据库连接
         self.db = pymysql.connect(
             host=dbdata['host'],
@@ -30,6 +29,8 @@ class MySQLClient:
         :param value 需要转换的字符串
         :return 编码后的字符串
         '''
+        if type(value) == int:
+            return value
         return html.escape(value)
 
     def html_unescape(self, value: str):
@@ -42,7 +43,7 @@ class MySQLClient:
 
     def insert(self, table: str, data: dict, close: bool = True):
         '''
-        插入数据
+        插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
         :param table 表名
         :param data 需要插入的数据
         :param close 是否自动关闭数据库连接，默认True
@@ -77,12 +78,12 @@ class MySQLClient:
 
     def fetch(self, fields: list, table: str, query: str, close: bool = True):
         '''
-        查询数据
+        查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param fields 要查询的字段名
         :param table 表名
         :param query 查询条件
         :param close 是否自动关闭数据库连接，默认True
-        :return {tuple} 如果没有查询结果，则返回None
+        :return {list} 如没有查询结果则返回None
         '''
         sql = 'SELECT %s FROM %s WHERE %s' % (
             ','.join(fields),
@@ -99,23 +100,37 @@ class MySQLClient:
         # 关闭数据库连接
         if close:
             self.close()
+        # 没有查询结果则返回None
         if len(results) == 0:
             return None
-        return results
+        # 转化查询结果为list
+        res_data = []
+        col_count = len(fields)
+        for result in results:
+            col_data = {}
+            for col in range(col_count):
+                col_data[fields[col]] = result[col]
+            res_data.append(col_data)
+        return res_data
 
-    def update(self, table: str, set: str, query: str, close: bool = True):
+    def update(self, table: str, set: dict, query: str, close: bool = True):
         '''
-        更新数据
+        更新数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param table 表名
-        :param set 修改内容
+        :param set 需要修改的内容
         :param query 查询条件
         :param close 是否自动关闭数据库连接，默认True
         :return {bool} True/False
         '''
         result = False
+        set_list = []
+        for key in set.keys():
+            set_list.append(
+                '%s="%s"' % (key, self.html_escape(set[key]))
+            )
         sql = 'UPDATE %s SET %s WHERE %s' % (
             table,
-            set,
+            ','.join(set_list),
             query
         )
         try:
@@ -135,7 +150,7 @@ class MySQLClient:
 
     def delete(self, table: str, query: str, close: bool = True):
         '''
-        删除数据
+        删除数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param table 表名
         :param query 查询条件
         :param close 是否自动关闭数据库连接，默认True
