@@ -2,22 +2,19 @@ import oss2
 
 
 class AliyunClass:
-    def __init__(self, AccessKeyId: str, AccessKeySecret: str, endpoint: str, bucket_name: str):
+    def __init__(self, ossdata: dict):
         '''
         RAM用户的AccessKey信息
-        :param AccessKeyId AccessKeyId
-        :param AccessKeySecret AccessKeySecret
-        :param endpoint Endpoint（地域节点）外网访问地址，带https://
-        :param bucket_name Bucket名称
+        :param ossdata AccessKeyId,AccessKeySecret,endpoint(Endpoint（地域节点）外网访问地址，带https://),bucket_name(Bucket名称)
         '''
         self.auth = oss2.Auth(
-            AccessKeyId,
-            AccessKeySecret
+            ossdata['AccessKeyId'],
+            ossdata['AccessKeySecret']
         )
         self.bucket = oss2.Bucket(
             self.auth,
-            endpoint,
-            bucket_name,
+            ossdata['endpoint'],
+            ossdata['bucket_name'],
             connect_timeout=30
         )
 
