@@ -16,7 +16,7 @@ class StrClass:
         '''
         创建纯数字随机字符串
         :param length 生成的字符串长度
-        return {str} 生成的随机字符串
+        :return {str} 生成的随机字符串
         '''
         result = ''
         pool = '0123456789'
@@ -29,7 +29,7 @@ class StrClass:
         '''
         创建包含大小写字母和数字的随机字符串
         :param length 生成的字符串长度
-        return {str} 生成的随机字符串
+        :return {str} 生成的随机字符串
         '''
         result = ''
         pool = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz0123456789'
@@ -43,7 +43,7 @@ class StrClass:
         创建自定义范围的随机字符串
         :param pool 自定义字符串范围
         :param length 生成的字符串长度
-        return {str} 生成的随机字符串
+        :return {str} 生成的随机字符串
         '''
         result = ''
         pool_len = len(pool)-1
@@ -55,7 +55,7 @@ class StrClass:
         """
         字符串md5加密
         :param enstr 需要加密的字符串
-        return {str} 加密后的字符串
+        :return {str} 加密后的字符串
         """
         md = hashlib.md5()
         md.update(bytes(enstr, encoding='utf-8'))
@@ -66,7 +66,7 @@ class StrClass:
         """
         字符串sha1加密
         :param enstr 需要加密的字符串
-        return {str} 加密后的字符串
+        :return {str} 加密后的字符串
         """
         sha = hashlib.sha1()
         sha.update(bytes(enstr, encoding='utf-8'))
@@ -78,7 +78,7 @@ class StrClass:
         根据原密码加盐获取新的加密密码
         :param pwd 原密码
         :param salt 盐值，盐值长度必须大于4
-        return {str} 加密后的密码
+        :return {str} 加密后的密码
         """
         salt1 = salt[0:4]
         salt2 = salt[4:]
@@ -88,8 +88,8 @@ class StrClass:
     def access_token(self, uniqueid: str):
         """
         生成唯一access_token
-        :param pwdStr 原密码
-        :param salt 盐值，盐值长度必须大于4
+        :param uniqueid 唯一id
+        :return {str}
         """
         timeclass = TimeClass()
         result = str(uniqueid)+str(timeclass.timestamp())
